
.. _custom_test_support:

Custom Test Support
===================

.. contents::

pytest fixtures
---------------

.. automodule:: pyfrc.test_support.pytest_plugin
   :members:

Controlling the robot's state
-----------------------------

.. automodule:: pyfrc.test_support.controller
   :members:
